#!/usr/bin/env python
#
# vi: ts=8 sts=4 sw=4 et
#
# runtask.py: run a scheduled task
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2002 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: dracotask.py,v 1.7 2003/03/19 11:08:59 geertj Exp $

import sys
import draco

from draco.util import reindent, getBacktrace


def usage():
    print >>sys.stderr, 'Draco version %s' % draco.cfg_version
    print >>sys.stderr, 'Usage: %s DOC-ROOT TASK-NAME\n' % sys.argv[0]
    print >>sys.stderr, '  DOC-ROOT    : the document root of the web application'
    print >>sys.stderr, '  TASK-NAME   : the name of the task to run'


if len(sys.argv) != 3:
    usage()
    sys.exit(1)

docroot = sys.argv[1]
taskname = sys.argv[2]

options = { 'DocumentRoot': sys.argv[1] }

from draco import logger as mlogger
logfile = docroot + '/error.log'
logger = mlogger.logger = mlogger.Logger(logfile)

from draco import config as mconfig
cfgfiles = draco.cfg_datadir + '/draco.ini', docroot + '/draco.ini'
config = mconfig.config = mconfig.Config(cfgfiles)
config.reload(options)

from draco import database as mdatabase
factory = mdatabase.DatabaseFactory()
factory.configure(config)
database = mdatabase.database = factory.createDatabase()
database.configure(config)
database.reload()
dbapi = mdatabase.dbapi = factory.createDbapi()

from draco import loader as mloader
loader = mloader.loader = mloader.Loader()
loader.configure(config)

sys.path.insert(0, docroot + '/__lib__')

files = docroot + '/__tasks__.py', draco.cfg_datadir + '/lib/__tasks__.py'
for fi in files:
    try:
        tasks = loader.load(fi)
    except SyntaxError, err:
        logger.error('Syntax error in task file, line %d' % err.lineno)
        continue
    if taskname in dir(tasks):
        tclass = getattr(tasks, taskname)
        break
else:
    logger.error('Task %s not found.' % taskname)
    sys.exit(2)

logger.info('Running task %s' % taskname)
try:
    task = tclass()
    task.run()
except:
    exc, value, trace = sys.exc_info()
    try:
        name = exc.__name__
    except AttributeError:
        name = str(exc)
    value = str(value)
    logger.error("""** Un unhandled exception occurred in a task **\n
            Exception: %s
            Value: %s\n
            %s
            """, (name, value, reindent(getBacktrace(), '++  ', 0)))
    sys.exit(3)

sys.exit(0)
