# vi: ts=4 sw=4 et
#
# __init__.py: main package definitions
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2002 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: __init__.py,v 1.27 2003/03/18 14:55:13 geertj Exp $

# These are set up by the setup.py script, do not change.

cfg_version = "0.99.4"
cfg_bindir = "/usr/local/bin"
cfg_datadir = "/usr/local/share/draco"

__all__ = ('application', 'client', 'config', 'cookie', 'database',
    'date', 'dbmysql', 'dbnull', 'dbpgsql', 'document', 'dracohandler',
    'encode', 'environment', 'event', 'filewatch', 'form', 'handler',
    'image', 'loader', 'logger', 'namespace', 'request', 'response',
    'rewrite', 'server', 'session', 'task', 'user', 'util',)


class HttpResponse(Exception):
    """
    Base class of all http responses.
    """

# REDIRECTION (3xx)


class HttpRedirect(HttpResponse):
    """
    Base class of all redirection responses.
    """

class HttpMovedPermanently(HttpRedirect):
    """
    A resource has been moved permanently.
    """
    code = 301

class HttpFound(HttpRedirect):
    """
    A resource was found but resides under a different URI.
    """
    code = 302


# REQUEST ERRORS (4xx)

class HttpClientError(HttpResponse):
    """
    A client error has occurred.
    """

class HttpBadRequest(HttpClientError):
    """
    An illegal request has been made.
    """
    code = 400

class HttpForbidden(HttpClientError):
    """
    Access to a resource was denied.
    """
    code = 403

class HttpNotFound(HttpClientError):
    """
    A resource was not found.
    """
    code = 404

class HttpGone(HttpClientError):
    """
    A resource is permanently gone.
    """
    code = 410


# SERVER ERRORS (5xx)

class HttpServerError(HttpResponse):
    """
    A server error has occurred.
    """

class HttpInternalServerError(HttpServerError):
    """
    An internal server error has occurred.
    """
    code = 500

class HttpServiceUnavailable(HttpServerError):
    """
    A resource is temporarily unavailable.
    """
    code = 503
