# vi: ts=4 sw=4 et
#
# client.py: the Client object
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2003 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: client.py,v 1.2 2003/03/10 16:38:37 geertj Exp $

import socket


class Client:
    """
    This class provides some information about the remote client.
    """

    def __init__(self):
        pass

    def configure(self, config):
        pass

    def reload(self, mpreq):
        """
        Reload the client object.
        """
        self.m_mpreq = mpreq

    def address(self):
        """
        Return the address the remote client
        """
        return self.m_mpreq.connection.remote_addr[0]

    def port(self):
        """
        Return the port number from which the remote client is connected.
        """
        return self.m_mpreq.connection.remote_addr[1]

    def hostname(self):
        """
        Return the hostname of the remote client.
        """
        host = self.m_mpreq.connection.remote_host
        if host is None:
            try:
                host = socket.gethostbyaddr(self.address())[0]
            except socket.herror:
                pass
        if not host:
            host = self.address()
        return host
