# vi: ts=4 sw=4 et
#
# dbnull.py: null database access
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2003 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: dbnull.py,v 1.2 2003/03/17 11:27:19 geertj Exp $

import draco
from draco.database import Database, DatabaseNamespace

dbapi = None


class NullDatabase(Database):
    """
    A special "null" database that allows no data access.
    """

    def configure(self, config):
        pass

    def reload(self):
        pass

    def finalize(self):
        pass

    def __nonzero__(self):
        return 0

    def connection(self):
        raise draco.HttpInternalServerError, 'Null database.'

    def cursor(self):
        raise draco.HttpInternalServerError, 'Null database.'

    def checkTables(self):
        pass

    def createNamespace(self, table, discr, value, scope):
        return NullNamespace(self, table, discr, value, scope)


class NullNamespace(DatabaseNamespace):
    """
    A namespace for the null database. All data accesses are invalid and will
    raise a HttpInternalServerError exception.
    """

    def available(self):
        return 0

    def __len__(self):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def __getitem__(self, name):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def __setitem__(self, name, value):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def __delitem__(self, name):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def __contains__(self, name):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def items(self):
        raise draco.HttpInternalServerError, 'Null namespace.'

    def clear(self):
        raise draco.HttpInternalServerError, 'Null namespace.'
