# vi: ts=4 sw=4 et
#
# filewatch.py: watch file modifications
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (c) 1999-2003 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: filewatch.py,v 1.4 2003/03/10 16:38:37 geertj Exp $

import os


class FileWatch:
    """
    A utility class to watch a file or set of files for modifications.
    """

    def __init__(self, files=()):
        """
        Initialize the file watch with `files'.
        """
        self.m_files = files
        self.m_mtime = {}

    def _modified(self, fname):
        """
        Return nonzero if `fname' was modified since the last call or if
        this is the first call.
        """
        try:
            st = os.stat(fname)
            if fname in self.m_mtime and st.st_mtime <= self.m_mtime[fname]:
                return 0
            self.m_mtime[fname] = st.st_mtime
        except OSError:
            if fname in self.m_mtime and self.m_mtime[fname] is None:
                return 0
            self.m_mtime[fname] = None
        return 1

    def modified(self, fname=None):
        """
        Return nonzero if any of the watched files has changed since the
        last call or if this is the first call.
        """
        if fname is None:   
            files = self.m_files
        else:
            files = (fname,)
        return len(filter(self._modified, files))

    def clear(self, fname=None):
        """
        Clear the timestamp for a file `fname'.
        """
        if fname is None:
            self.m_mtime.clear()
        elif self.m_mtime.has_key(fname):
            del self.m_mtime[fname]
