# vi: ts=4 sw=4 et
#
# loader.py: Contains Loader, a module loader.
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2003 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: loader.py,v 1.16 2003/03/10 16:38:37 geertj Exp $

import os
import os.path
import sys
import imp


class Loader:
    """
    Module loader. Modules are not cached here, this should be done in
    higher level code.
    """

    def configure(self, config):
        pass

    def reload(self):
        pass

    def load(self, fname):
        """
        Load and cache the python source FNAME and return it as a module.
        """
        fname = os.path.normpath(fname)  # Nicer filenames in error logs
        try:
            mfile = file(fname)
        except IOError:
            return
        # The module name will be used by Python as a key in sys.modules. It
        # must be unique for all loaded files and must not contain a period.
        mname = fname.replace('!', '!!').replace('.', '!')
        try:
            module = imp.load_source(mname, fname, mfile)
        finally:
            mfile.close()
        return module
