# vi: ts=4 sw=4 et
#
# logger.py: logging functions
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2002 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: logger.py,v 1.4 2003/03/26 09:36:59 geertj Exp $

import time
import fcntl

from draco.util import reindent


class Logger:
    """
    Logger class that can log to a single file.
    """

    def __init__(self, file):
        self.m_file = file

    def write(self, message):
        try:
            flog = file(self.m_file, 'a')
        except IOError:
            return
        fcntl.lockf(flog, fcntl.LOCK_EX)
        try:
            flog.write(message)
            flog.flush()
        finally:
            fcntl.lockf(flog, fcntl.LOCK_UN)
        flog.close()

    def format(self, message, args, type):
        message = reindent(message) % args
        message = reindent(message, indent='++  ')
        entry = '[%s] [%s]: %s\n' % (time.ctime(), type, message)
        self.write(entry)

    def debug(self, message, args=()):
        self.format(message, args, 'debug')

    def info(self, message, args=()):
        self.format(message, args, 'info')

    def warn(self, message, args=()):
        self.format(message, args, 'warn')

    def error(self, message, args=()):
        self.format(message, args, 'error')
