# vi: ts=4 sw=4 et
#
# user.py: the user namespace
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2003 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: user.py,v 1.6 2003/03/17 11:27:20 geertj Exp $

from draco.namespace import NamespaceBridge
from draco.database import database


class UserNamespace(NamespaceBridge):
    """
    The "user" namespace. This namespace is bound to the userid of the
    current session, if the session is logged in. If not, the namespace is
    not available and operations on it will fail.

    All user namespaces have a scope. User namespaces with a different scope
    are independent.
    """

    def setScope(self, userid, scope):
        namespace = database.createNamespace('draco_user_data',
                        'userid', userid, scope)
        self.setNamespace(namespace)


class User(UserNamespace):
    """
    The global User object. It provides direct access to the default
    ('__system__') user namespace and can construct subnamespaces.
    """

    def configure(self, config):
        pass

    def reload(self):
        """
        Reload the User object.
        """
        from draco.session import session
        self.m_userid = session.userid()
        self.setScope(self.m_userid, '__system__')

    def __nonzero__(self):
        """
        Return nonzero if the user namespaces are available.
        """
        return self.available()

    def namespace(self, scope):
        """
        Return the independent subnamespace with scope SCOPE.
        """
        namespace = UserNamespace()
        namespace.setScope(self.m_userid, scope)
        return namespace
