# vi: ts=4 sw=4 et
#
# __rewrite__.py: the system task rewriter
#
# This file is part of Draco, a dynamic web content system in Python.
# Draco is copyright (C) 1999-2002 Geert Jansen <geert@boskant.nl>.
# You can freely use and distribute this software under the terms of the
# GNU General Public License, version 2. See the file "LICENSE" included
# with this package for the exact licensing terms.
#
# $Id: __rewrite__.py,v 1.5 2003/03/10 16:38:37 geertj Exp $

from draco.rewrite import Rewriter
from draco.config import config
from draco.session import addSessionId
from draco.image import imagemanager


class SystemRewriter(Rewriter):
    """
    Draco's internal tag rewriter. It contains the necessary functionality
    for session management, and adds with/height attributes to images.
    """

    def __init__(self):
        """
        Initialize the rewriter.
        """
        self.m_addsize = config.get('ImageSizeDetect', 1)
        self.m_appendsid = config.get('SessionAppendUrl', 1)

    def a(self, tag):
        """
        Add session id to the `href' attribute of <a> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('href'):
            return
        tag.attrs['href'] = addSessionId(tag.attrs['href'])

    def form(self, tag):
        """
        Add session id to the `action' attribute of <form> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('action'):
            return
        tag.attrs['action'] = addSessionId(tag.attrs['action'])

    def area(self, tag):
        """
        Add session id to the `href' attribute of <area> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('href'):
            return
        tag.attrs['href'] = addSessionId(tag.attrs['href'])

    def link(self, tag):
        """
        Add session id to the `href' attribute of <link> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('href'):
            return
        tag.attrs['href'] = addSessionId(tag.attrs['href'])

    def frame(self, tag):
        """
        Add session id to the `src' attribute of <frame> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('src'):
            return
        tag.attrs['src'] = addSessionId(tag.attrs['src'])

    def iframe(self, tag):
        """
        Add session id to the `src' attribute of <iframe> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('src'):
            return
        tag.attrs['src'] = addSessionId(tag.attrs['src'])

    def script(self, tag):
        """
        Add session id to the `src' attribute of <script> tags.
        """
        if not self.m_appendsid or not tag.attrs.get('src'):
            return
        tag.attrs['src'] = addSessionId(tag.attrs['src'])

    def img(self, tag):
        """
        Try to discover width and height attributes for the image
        if they are not both specified. Add the session id too.
        """
        if not tag.attrs.get('src'):
            return
        if self.m_addsize and not tag.attrs.has_key('width'):
            size = imagemanager.lookup(tag.attrs['src'])
            if size:
                tag.attrs['width'] = str(size[0])
                tag.attrs['height'] = str(size[1])
        if self.m_appendsid:
            tag.attrs['src'] = addSessionId(tag.attrs['src'])
